@@ -1,17 +1,16 @@
 package Crypt::SecretBuffer::PEM;
 # VERSION
 # ABSTRACT: Parse PEM format from a SecretBuffer
-$Crypt::SecretBuffer::PEM::VERSION = '0.017_002'; # TRIAL
-$Crypt::SecretBuffer::PEM::VERSION = '0.017002';
+$Crypt::SecretBuffer::PEM::VERSION = '0.013';
 use strict;
 use warnings;
 use Carp;
 use Scalar::Util qw( blessed );
-use Crypt::SecretBuffer qw/ secret span MATCH_NEGATE MATCH_MULTI ISO8859_1 BASE64 /;
+use Crypt::SecretBuffer qw/ secret MATCH_NEGATE MATCH_MULTI ISO8859_1 BASE64 /;
 
 
 sub parse {
-   my ($class, $span, %options)= @_;
+   my ($class, $span)= @_;
    while (my $begin= $span->scan("-----BEGIN ")) {
       $span->pos($begin->lim);
       my $label= $span->parse(qr/[A-Z0-9 ]+/);
@@ -39,19 +38,14 @@ sub parse {
       my @headers;
       while (my $sep_or_eol= $inner->scan(qr/[:\n]/)) {
          if ($sep_or_eol->starts_with(':')) {
-            my ($name, $value);
+            my $name;
             $inner->clone(lim => $sep_or_eol->pos)->copy_to($name);
             $inner->pos($sep_or_eol->lim);
             my $eol= $inner->scan("\n") or die "BUG"; # inner ends with "\n", checked above
-            my $val_span= $inner->clone(lim => $eol->pos)
-               ->ltrim(' '); # remove one optional space character following ':'
+            my $value= $inner->clone(lim => $eol->pos);
+            $value->ltrim(' '); # remove one optional space character
             $inner->pos($eol->lim);
-            if ($options{secret_headers}) {
-               push @headers, $name, $val_span;
-            } else {
-               $val_span->copy_to($value);
-               push @headers, $name, $value;
-            }
+            push @headers, $name, $value;
          }
          else {
             # If any headers were found, there needs to be a blank line
@@ -77,9 +71,9 @@ sub parse {
 }
 
 sub parse_all {
-   my ($class, $span, %options)= @_;
+   my ($class, $span)= @_;
    my @pem;
-   while (my $pem= $class->parse($span, %options)) {
+   while (my $pem= $class->parse($span)) {
       push @pem, $pem;
    }
    return @pem;
@@ -116,21 +110,21 @@ sub serialize {
    if (@header_kv) {
       while (@header_kv) {
          my ($k, $v)= splice @header_kv, 0, 2;
-         # Sanity checks, key cannot contain control chars or ':'
-         croak "PEM Header name '$k' contains ':' or control characters"
+         # Sanity checks, key cannot contain control chars or :
+         croak "PEM Header name cannot contain ':' or control characters"
             if $k =~ /[\0-\x1F:]/;
-         croak "PEM header value for '$k' must be defined"
-            unless defined $v;
-         croak "PEM header value for '$k' contains a newline"
+         croak "PEM value cannot contain newline"
             if blessed($v) && $v->can('scan')? $v->scan("\n") : $v =~ /\n/;
          $out->append("$k: ")->append($v)->append("\n");
       }
       $out->append("\n"); # empty line terminates headers
    }
-   my $content_span= span($self->content);
-   $content_span->append_to($out, encoding => BASE64);
-   $out->append(($content_span->length? "\n" : '')
-                .'-----END '.$self->label."-----\n");
+   if ($self->content->encoding == BASE64) {
+      $out->append($self->content);
+   } else {
+      $out->append($self->content->copy(encoding => BASE64));
+   }
+   $out->append('-----END '.$self->label."-----\n");
    return $out;
 }
 
@@ -159,40 +153,25 @@ of a block of Base64 data with optional headers and begin/end markers.  This mod
 begin/end markers, copies that span of bytes into a new SecretBuffer, makes the attributes into
 a hash, and marks the Base64 span in case you want to process the bytes.
 
-To be clear, this only parses the I<text portions> of PEM, I<not the ASN.1 structure> within the
-base64 data.
-
 The label around the PEM block and the keys of its headers (if any) are considered non-secret,
 and copied out of the SecretBuffer into perl scalars.  The values of the headers, and the Base64
-payload remain inside secret Span objects.
+payload remain secret.
 
 =head1 CONSTRUCTORS
 
 =head2 parse
 
-  my $pem= Crypt::SecretBuffer::PEM->parse($span, %options);
+  my $pem= Crypt::SecretBuffer::PEM->parse($span);
 
 Parse the next PEM block found in the L<Span|Crypt::SecretBuffer::Span>.  The span is updated to
-begin on the line following the PEM block.  If no PEM block is found, the span object remains
-unchanged.
+begin on the line following the PEM block.  If no PEM block is found, the span is unaltered.
 
 Invalid PEM blocks (such as mismatched BEGIN/END markers) are ignored, as well as any text
 outside of the markers.
 
-Options:
-
-=over
-
-=item secret_headers
-
-Whether the values of the PEM headers should be stored in L<Crypt::SecretBuffer::Span> objects.
-Default is false.
-
-=back
-
 =head2 parse_all
 
-  my @pem_blocks= Crypt::SecretBuffer::PEM->parse_all($span, %options);
+  my @pem_blocks= Crypt::SecretBuffer::PEM->parse_all($span);
 
 A file can contain more than one PEM block (such as a SSL certificate chain, and its key)
 This just calls L</parse> in a loop until no more PEM blocks are found.
@@ -201,7 +180,7 @@ This just calls L</parse> in a loop until no more PEM blocks are found.
 
   my $pem= Crypt::SecretBuffer::PEM->new(%attributes);
 
-You can construct a PEM object from attributes, in case you want to serialize your own data.
+You can construct a PEM object from attributes, in case you want to serialize one.
 
 =head1 ATTRIBUTES
 
@@ -213,7 +192,7 @@ The text from the PEM begin-marker:
    ...
    -----END SOME LABEL-----
 
-In this case the attribute would hold C<< 'SOME LABEL' >>.
+IN this case the attribute would hold C<< 'SOME LABEL' >>.
 
 =head2 buffer
 
@@ -232,7 +211,7 @@ Note that the values are L<Span|Crypt::SecretBuffer::Span> objects.
 
 =head2 content
 
-A L<Span|Crypt::SecretBuffer::Span> or SecretBuffer that contains the bytes of the PEM payload.
+A L<Span|Crypt::SecretBuffer::Span>  or SecretBuffer that contains the bytes of the PEM payload.
 
 =head1 METHODS
 
@@ -245,7 +224,7 @@ falling back to the L</headers> hashref.
 
 =head1 VERSION
 
-version 0.017_002
+version 0.013
 
 =head1 AUTHOR
 
@@ -253,7 +232,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Michael Conrad.
+This software is copyright (c) 2025 by Michael Conrad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
